@@ -44,12 +44,26 @@ void terminal_app_new_terminal (TerminalApp     *app,
                                 gboolean         force_menubar_state,
                                 gboolean         forced_menubar_state,
                                 char           **override_command,
-                                const char      *geometry);
+                                const char      *geometry,
+                                const char      *title,
+                                const char      *working_dir,
+                                const char      *role,
+                                double           zoom);
 
 void terminal_app_manage_profiles (TerminalApp     *app,
                                    GtkWindow       *transient_parent);
 
 void terminal_app_edit_keybindings (TerminalApp     *app,
                                     GtkWindow       *transient_parent);
+void terminal_app_edit_encodings   (TerminalApp     *app,
+                                    GtkWindow       *transient_parent);
+
+void terminal_util_set_labelled_by          (GtkWidget  *widget,
+                                             GtkLabel   *label);
+void terminal_util_set_atk_name_description (GtkWidget  *widget,
+                                             const char *name,
+                                             const char *desc);
+
+
 
 #endif /* TERMINAL_H */
